<TS language="lv" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Izveidot jaunu adresi</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Jauns</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Kopēt iezīmēto adresi uz starpliktuvi</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopēt</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Aizvērt</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Izdzēst iezīmētās adreses no saraksta</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>Ierakstiet meklējamo nosaukumu vai adresi</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Datus no tekošā ieliktņa eksportēt uz failu</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Eksportēt</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Dzēst</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Izvēlies adresi uz kuru sūtīt bitcoins</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Izvēlies adresi ar kuru saņemt bitcoins</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>Izvēlēties</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>Adrešu nosūtīšana</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>Adrešu saņemšana</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>Šīs ir jūsu Bitcoin adreses, kuras izmantojamas maksājumu veikšanai. Vienmēr pārbaudiet summu un saņēmēja adresi pirms monētu nosūtīšanas.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;Kopēt adresi</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Kopēt &amp;Marķējumu</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Rediģēt</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>Eksportēt Adrešu Sarakstu</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Ar komatiem atdalīts fails (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Eksportēšana Neizdevās</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>Mēģinot saglabāt adrešu sarakstu %1 radās kļūda. Mēģiniet vēlreiz.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Nosaukums</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adrese</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(bez nosaukuma)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Paroles dialogs</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Ierakstiet paroli</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Jauna parole</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Jaunā parole vēlreiz</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation>Rādīt paroli</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Šifrēt maciņu</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Lai veiktu šo darbību, nepieciešama jūsu maciņa slepenā frāze maciņa atvēršanai.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Atslēgt maciņu</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Lai veiktu šo darbību, nepieciešama jūsu maciņa slepenā frāze maciņa dekriptēšanai.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Atšifrēt maciņu</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Mainīt paroli</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Apstiprināt maciņa šifrēšanu</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation>Brīdinājums: Šifrējot Jūsu maciņu, gadījumā ja aizmirsīsiet savu paroli, Jūs NEATGRIEZENISKI ZAUDĒSIET VISUS SAVUS "BITKOINUS"!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Vai tu tiešām vēlies šifrēt savu maciņu?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Maciņš šifrēts</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Ievadiet savu paroli Jūsu maciņam, lūdzu lietojiet vismaz desmit simbolus, astoņus vai vairāk vārdus.</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation>Ievadiet veco un jauno paroli Jūsu maciņam</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation>Maciņu nepieciešams šifrēt.</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation>Maciņš tagad šifrēts</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Maciņa šifrēšana neizdevās</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Maciņa atslēgšana neizdevās</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>Maciņa atšifrēšana neizdevās</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Parakstīt &amp;ziņojumu...</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Sinhronizācija ar tīklu...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Pārskats</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Rādīt vispārēju maciņa pārskatu</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Transakcijas</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Skatīt transakciju vēsturi</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Iziet</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Aizvērt programmu</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>&amp;Par %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>Parādīt informāciju par %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Par &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Parādīt informāciju par Qt</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Iespējas...</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>Šifrēt &amp;maciņu...</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>&amp;Maciņa Rezerves Kopija...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>Mainīt &amp;Paroli...</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>Atvērt &amp;URI...</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>Maciņš:</translation>
    </message>
    <message>
        <source>Reindexing blocks on disk...</source>
        <translation>Bloku reindeksēšana no diska...</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation>Nosūtīt bitkoinus uz Bitcoin adresi</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation>Izveidot maciņa rezerves kopiju citur</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Mainīt maciņa šifrēšanas paroli</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Pārbaudīt ziņojumu...</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Sūtīt</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Saņemt</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Rādīt / Paslēpt</translation>
    </message>
    <message>
        <source>Show or hide the main Window</source>
        <translation>Parādīt vai paslēpt galveno Logu</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation>Šifrēt privātās atslēgas kuras pieder tavam maciņam</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation>Parakstīt ziņojumus ar savām Bitcoin adresēm lai pierādītu ka tās pieder tev</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation>Pārbaudīt ziņojumus lai pārliecinātos, ka tie tika parakstīti ar norādītajām Bitcoin adresēm</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fails</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Uzstādījumi</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Palīdzība</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>Ciļņu rīkjosla</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation>Pieprasīt maksājumus (izveido QR kodu un bitcoin: URIs)</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation>&amp;Komandrindas iespējas</translation>
    </message>
    <message>
        <source>Indexing blocks on disk...</source>
        <translation>Bloku reindeksēšana no diska...</translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation>%1 aizmugurē</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation>Transakcijas pēc šī vel nebūs redzamas</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Kļūda</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Brīdinājums</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informācija</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Sinhronizēts</translation>
    </message>
    <message>
        <source>Open node debugging and diagnostic console</source>
        <translation>Atvērt atkļūdošanas un diagnostikas konsoli</translation>
    </message>
    <message>
        <source>&amp;Sending addresses</source>
        <translation type="unfinished">&amp;Adrešu nosūtīšana</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses</source>
        <translation type="unfinished">&amp;Adrešu saņemšana</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Logs</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Sinhronizējos...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Transakcija nosūtīta</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Ienākoša transakcija</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation>Maciņš ir &lt;b&gt;šifrēts&lt;/b&gt; un pašlaik &lt;b&gt;atslēgts&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Maciņš ir &lt;b&gt;šifrēts&lt;/b&gt; un pašlaik &lt;b&gt;slēgts&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Daudzums:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Baiti:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Daudzums:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Maksa:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Pēc Maksas:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Atlikums:</translation>
    </message>
    <message>
        <source>(un)select all</source>
        <translation>iezīmēt visus</translation>
    </message>
    <message>
        <source>Tree mode</source>
        <translation>Koka režīms</translation>
    </message>
    <message>
        <source>List mode</source>
        <translation>Saraksta režīms</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Daudzums</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datums</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Apstiprinājumi</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Apstiprināts</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation>&amp;Kopēt adresi</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation>Kopēt &amp;Marķējumu</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(bez nosaukuma)</translation>
    </message>
    </context>
<context>
    <name>CreateWalletActivity</name>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Wallet</source>
        <translation>Maciņš</translation>
    </message>
    <message>
        <source>Encrypt Wallet</source>
        <translation type="unfinished">Šifrēt maciņu</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Mainīt adrese</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Nosaukums</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Adrese</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>A new data directory will be created.</source>
        <translation>Tiks izveidota jauna datu mape.</translation>
    </message>
    <message>
        <source>name</source>
        <translation>vārds</translation>
    </message>
    <message>
        <source>Path already exists, and is not a directory.</source>
        <translation>Šāds ceļš jau pastāv un tā nav mape.</translation>
    </message>
    <message>
        <source>Cannot create data directory here.</source>
        <translation>Šeit nevar izveidot datu mapi.</translation>
    </message>
</context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation>versija</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation type="unfinished">Par %1</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation>Komandrindas iespējas</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation>Sveiciens</translation>
    </message>
    <message>
        <source>Use the default data directory</source>
        <translation>Izmantot noklusēto datu mapi</translation>
    </message>
    <message>
        <source>Use a custom data directory:</source>
        <translation>Izmantot pielāgotu datu mapi:</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Kļūda</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation>Forma</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Pēdējā bloka laiks</translation>
    </message>
    </context>
<context>
    <name>NetWatchLogModel</name>
    <message>
        <source>Address</source>
        <comment>NetWatch: Address header</comment>
        <translation>Adrese</translation>
    </message>
</context>
<context>
    <name>OpenURIDialog</name>
    <message>
        <source>Paste address from clipboard</source>
        <translation>ielīmēt adresi no starpliktuves</translation>
    </message>
    </context>
<context>
    <name>OpenWalletActivity</name>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Iespējas</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Galvenais</translation>
    </message>
    <message>
        <source>Size of &amp;database cache</source>
        <translation>&amp;Datubāzes kešatmiņas izmērs</translation>
    </message>
    <message>
        <source>Number of script &amp;verification threads</source>
        <translation>Skriptu &amp;pārbaudes pavedienu skaits</translation>
    </message>
    <message>
        <source>IP address of the proxy (e.g. IPv4: 127.0.0.1 / IPv6: ::1)</source>
        <translation>Starpniekservera IP adrese (piem. IPv4: 127.0.0.1 / IPv6: ::1)</translation>
    </message>
    <message>
        <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Exit in the menu.</source>
        <translation>Minimizēt nevis aizvērt aplikāciju, kad logs tiek aizvērts. Kad šī iespēja ir ieslēgta, aplikācija tiks aizvērta, izvēloties Aizvērt izvēlnē.</translation>
    </message>
    <message>
        <source>Reset all client options to default.</source>
        <translation>Atiestatīt visus klienta iestatījumus uz noklusējumu.</translation>
    </message>
    <message>
        <source>&amp;Reset Options</source>
        <translation>&amp;Atiestatīt Iestatījumus.</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Tīkls</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation>&amp;Maciņš</translation>
    </message>
    <message>
        <source>Expert</source>
        <translation>Eksperts</translation>
    </message>
    <message>
        <source>Enable coin &amp;control features</source>
        <translation>Ieslēgt bitcoin &amp;kontroles funkcijas</translation>
    </message>
    <message>
        <source>&amp;Spend unconfirmed change</source>
        <translation>&amp;Tērēt neapstiprinātu atlikumu</translation>
    </message>
    <message>
        <source>Automatically open the Bitcoin client port on the router. This only works when your router supports UPnP and it is enabled.</source>
        <translation>Uz rūtera automātiski atvērt Bitcoin klienta portu. Tas strādā tikai tad, ja rūteris atbalsta UPnP un tas ir ieslēgts.</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Kartēt portu, izmantojot &amp;UPnP</translation>
    </message>
    <message>
        <source>Proxy &amp;IP:</source>
        <translation>Starpniekservera &amp;IP:</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;Ports:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Starpniekservera ports (piem. 9050)</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Logs</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Pēc loga minimizācijas rādīt tikai ikonu sistēmas teknē.</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;Minimizēt uz sistēmas tekni, nevis rīkjoslu</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>M&amp;inimizēt aizverot</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Izskats</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>Lietotāja interfeiss un &amp;valoda:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>&amp;Vienības, kurās attēlot daudzumus:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Izvēlēties dalījuma vienību pēc noklusēšanas, ko izmantot interfeisā un nosūtot bitkoinus.</translation>
    </message>
    <message>
        <source>Whether to show coin control features or not.</source>
        <translation>Vai rādīt Bitcoin kontroles funkcijas vai nē.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Labi</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Atcelt</translation>
    </message>
    <message>
        <source>default</source>
        <translation>pēc noklusēšanas</translation>
    </message>
    <message>
        <source>none</source>
        <translation>neviena</translation>
    </message>
    <message>
        <source>Confirm options reset</source>
        <translation>Apstiprināt iestatījumu atiestatīšanu</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Kļūda</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>Norādītā starpniekservera adrese nav derīga.</translation>
    </message>
</context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Forma</translation>
    </message>
    <message>
        <source>The displayed information may be out of date. Your wallet automatically synchronizes with the Bitcoin network after a connection is established, but this process has not completed yet.</source>
        <translation>Attēlotā informācija var būt novecojusi. Jūsu maciņš pēc savienojuma izveides automātiski sinhronizējas ar Bitcoin tīklu, taču šis process vēl nav beidzies.</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>Pieejams:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>Tava pašreizējā tērējamā bilance</translation>
    </message>
    <message>
        <source>Pending:</source>
        <translation>Neizšķirts:</translation>
    </message>
    <message>
        <source>Total of transactions that have yet to be confirmed, and do not yet count toward the spendable balance</source>
        <translation>Kopējā apstiprināmo transakciju vērtība, vēl nav ieskaitīta tērējamajā bilancē</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>Nenobriedušu:</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>Kopsumma:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>Jūsu kopējā tekošā bilance</translation>
    </message>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>Close</source>
        <translation type="unfinished">Aizvērt</translation>
    </message>
    </context>
<context>
    <name>PairingPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Daudzums</translation>
    </message>
    <message>
        <source>%1 h</source>
        <translation>%1 st</translation>
    </message>
    <message>
        <source>%1 and %2</source>
        <translation>%1 un %2</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>nav zināms</translation>
    </message>
    </context>
<context>
    <name>QRImageWidget</name>
    <message>
        <source>&amp;Save Image...</source>
        <translation>&amp;Saglabāt Attēlu...</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Client version</source>
        <translation>Klienta versija</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;Informācija</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Vispārējs</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>Sākuma laiks</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Tīkls</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Vārds</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Savienojumu skaits</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Bloku virkne</translation>
    </message>
    <message>
        <source>Wallet: </source>
        <translation type="unfinished">Maciņš: </translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Pēdējā bloka laiks</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Atvērt</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Konsole</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>&amp;Tīkla Satiksme</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>Ie.:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>Iz.:</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>Atkļūdošanas žurnāla datne</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Notīrīt konsoli</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <extracomment>Context menu action to copy the address of a peer</extracomment>
        <translation>&amp;Kopēt adresi</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation>&amp;Daudzums:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Nosaukums:</translation>
    </message>
    <message>
        <source>&amp;Message:</source>
        <translation>&amp;Ziņojums:</translation>
    </message>
    <message>
        <source>&amp;Request payment</source>
        <translation>&amp;Pieprasīt maksājumu</translation>
    </message>
    <message>
        <source>Clear all fields of the form.</source>
        <translation>Notīrīt visus laukus formā.</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Notīrīt</translation>
    </message>
    <message>
        <source>Requested payments history</source>
        <translation>Pieprasīto maksājumu vēsture</translation>
    </message>
    <message>
        <source>Show the selected request (does the same as double clicking an entry)</source>
        <translation>Parādīt atlasītos pieprasījumus (tas pats, kas dubultklikšķis uz ieraksta)</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Rādīt</translation>
    </message>
    <message>
        <source>Remove the selected entries from the list</source>
        <translation>Noņemt atlasītos ierakstus no saraksta.</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Noņemt</translation>
    </message>
    <message>
        <source>Copy &amp;URI</source>
        <translation>Kopēt &amp;URI</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation>&amp;Kopēt adresi</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation>Kopēt &amp;Marķējumu</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address:</source>
        <translation type="unfinished">Adrese:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Daudzums:</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation type="unfinished">Nosaukums:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Ziņojums:</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>Maciņš:</translation>
    </message>
    <message>
        <source>Copy &amp;URI</source>
        <translation>Kopēt &amp;URI</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation>Kopēt &amp;Adresi</translation>
    </message>
    <message>
        <source>&amp;Save Image...</source>
        <translation>&amp;Saglabāt Attēlu...</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>Datums</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Nosaukums</translation>
    </message>
    <message>
        <source>Message</source>
        <translation type="unfinished">Ziņojums</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(bez nosaukuma)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Sūtīt Bitkoinus</translation>
    </message>
    <message>
        <source>Coin Control Features</source>
        <translation>Bitcoin Kontroles Funkcijas</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>Ieejas...</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>automātiski atlasīts</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Nepietiekami līdzekļi!</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Daudzums:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Baiti:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Daudzums:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Maksa:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Pēc Maksas:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Atlikums:</translation>
    </message>
    <message>
        <source>Custom change address</source>
        <translation>Pielāgota atlikuma adrese</translation>
    </message>
    <message>
        <source>Transaction Fee:</source>
        <translation>Transakcijas maksa:</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation type="unfinished">Izvēlēties...</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Sūtīt vairākiem saņēmējiem uzreiz</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>&amp;Pievienot Saņēmēju</translation>
    </message>
    <message>
        <source>Clear all fields of the form.</source>
        <translation>Notīrīt visus laukus formā.</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>&amp;Notīrīt visu</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation>Bilance:</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Apstiprināt nosūtīšanu</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>&amp;Sūtīt</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Transakcijas maksa</translation>
    </message>
    <message>
        <source>Send</source>
        <translation type="unfinished">Sūtīt</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(bez nosaukuma)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>Apjo&amp;ms</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>&amp;Saņēmējs:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Nosaukums:</translation>
    </message>
    <message>
        <source>Choose previously used address</source>
        <translation>Izvēlies iepriekš izmantoto adresi</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>ielīmēt adresi no starpliktuves</translation>
    </message>
    <message>
        <source>Remove this entry</source>
        <translation>Noņem šo ierakstu</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Ziņojums:</translation>
    </message>
    <message>
        <source>Pay To:</source>
        <translation>Maksāt:</translation>
    </message>
    </context>
<context>
    <name>ShutdownWindow</name>
    <message>
        <source>Do not shut down the computer until this window disappears.</source>
        <translation>Neizslēdziet datoru kamēr šis logs nepazūd.</translation>
    </message>
</context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>Paraksti - Parakstīt / Pabaudīt Ziņojumu</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>Parakstīt &amp;Ziņojumu</translation>
    </message>
    <message>
        <source>Choose previously used address</source>
        <translation>Izvēlies iepriekš izmantoto adresi</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>ielīmēt adresi no starpliktuves</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>Šeit ievadi ziņojumu kuru vēlies parakstīt</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Paraksts</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>Kopēt parakstu uz sistēmas starpliktuvi</translation>
    </message>
    <message>
        <source>Sign the message to prove you own this Bitcoin address</source>
        <translation>Parakstīt ziņojumu lai pierādītu, ka esi šīs Bitcoin adreses īpašnieks.</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Parakstīt &amp;Ziņojumu</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>Atiestatīt visus laukus</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>&amp;Notīrīt visu</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Pārbaudīt Ziņojumu</translation>
    </message>
    <message>
        <source>Verify &amp;Message</source>
        <translation>&amp;Pārbaudīt Ziņojumu</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>Atiestatīt visus laukus</translation>
    </message>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation>Datums</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>nav zināms</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Transakcijas maksa</translation>
    </message>
    <message>
        <source>Message</source>
        <translation type="unfinished">Ziņojums</translation>
    </message>
    <message>
        <source>Transaction</source>
        <translation>Transakcijas</translation>
    </message>
    <message>
        <source>Inputs</source>
        <translation type="unfinished">Ieejas</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Daudzums</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Šis panelis parāda transakcijas detaļas</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Datums</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Nosaukums</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(bez nosaukuma)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>&amp;Copy address</source>
        <translation>&amp;Kopēt adresi</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation>Kopēt &amp;Marķējumu</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Ar komatiem atdalīts fails (*.csv)</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Apstiprināts</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datums</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Nosaukums</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adrese</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Eksportēšana Neizdevās</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Error</source>
        <translation>Kļūda</translation>
    </message>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Send Coins</source>
        <translation>Sūtīt Bitkoinus</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Eksportēt</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Datus no tekošā ieliktņa eksportēt uz failu</translation>
    </message>
    <message>
        <source>Backup Wallet</source>
        <translation type="unfinished">Maciņa Rezerves Kopija</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Atcelt</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Error loading block database</source>
        <translation>Kļūda ielādējot bloku datubāzi</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Kļūda</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Importē...</translation>
    </message>
    <message>
        <source>Verifying blocks...</source>
        <translation>Pārbauda blokus...</translation>
    </message>
    <message>
        <source>Signing transaction failed</source>
        <translation>Transakcijas parakstīšana neizdevās</translation>
    </message>
    <message>
        <source>Transaction amount too small</source>
        <translation>Transakcijas summa ir pārāk maza</translation>
    </message>
    <message>
        <source>Transaction too large</source>
        <translation>Transakcija ir pārāk liela</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>-onlynet komandā norādīts nepazīstams tīkls: '%s'</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Nepietiek bitkoinu</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Ielādē bloku indeksu...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Ielādē maciņu...</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Skanēju no jauna...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Ielāde pabeigta</translation>
    </message>
</context>
</TS>